@@ -1,5 +1,5 @@
 from django.core.management.commands import dumpdata
-from emailusernames.models import unmonkeypatch_user
+from emailusernames.models import unmonkeypatch_user, monkeypatch_user
 
 
 class Command(dumpdata.Command):
@@ -11,4 +11,6 @@ class Command(dumpdata.Command):
 
     def handle(self, *args, **kwargs):
         unmonkeypatch_user()
-        return super(Command, self).handle(*args, **kwargs)
+        ret = super(Command, self).handle(*args, **kwargs)
+        monkeypatch_user()
+        return ret
